# scplotlib

scplotlib is a python plotting library for the SingleCell (<https://github.com/edwinv87/singlecell>) object. It is built using Altair (<https://altair-viz.github.io/>). It can generate various plots for data stored in a SingleCell object such as:

1. Core plots - line plots, bar plots, scatter plots

2. Visualizing high dimensional data - t-SNE plots, PCA plots

3. Specialized plots - heatmaps, silhouette plots, outlier score plots
